gistools - Misc geospatial functions build upon geopandas
===================================================================

The gistools package is a bunch of misc convenience functions on top of geopandas, shapely, and rasterio for more complicated tasks.
Also included is a module that contains functions for catchment delineation of NIWA's REC network and associated functions.

Documentation
--------------
No docs yet...

Installation
------------
gistools can be installed via pip or conda::

  pip install gistools

or::

  conda install -c mullenkamp gistools
